<?php
include ("conexion.php");

$folio=$_POST['folio'];
$consfolio=$_POST['folio'];
$entrega=$_POST['entrega'];
$prod=$_POST['prod'];
$fecha=date("Y-m-d");

$entregados=0;
//============== INSERTAR ENTREGADOS
//echo "Listado de entregados<br>";
//primero hago el cambio de material
$total= sizeof($prod);

@$idcambio=$_POST['idcambio'];
@$cambio=$_POST['cambio'];

$prodcambio[]=0;
$prodidcambio[]=0;
for($x=0; $x < sizeof($prod); $x++)
{
	if ($entrega[$x]== "")
	{}
	else
	{
		//FOR PARA REGISTRAR CAMBIOS EN CONTABLES FIJOS
		for($y=0; $y < sizeof($idcambio); $y++)
		{
			$con1="SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$y]'";
			$res1=mysql_query($con1,$conex) or die ("No se realizó con1");
			$clave1=mysql_result($res1,0,'clave1');
			$clave2=mysql_result($res1,0,'clave2');
		
			if ($prod[$x]== $clave1)
			{
				$prodcambio[$x]=$cambio[$y];
				$prodidcambio[$x]=$idcambio[$y];
			}
			else
			{
				if ($prod[$x]== $clave2)
				{
					$prodcambio[$x]=$cambio[$y];
				}
			}
		}
		if (@$prodcambio[$x] != '')
		{
			//echo $prodidcambio[$x]." cambia ".$prod[$x]." por ".$prodcambio[$x]."<br>";
			
			//INICIA ACTUALIZACION DEL CAMBIO
			$con2="UPDATE contenido_salida SET idProducto='$prodcambio[$x]' WHERE idSalida='$folio' and idProducto='$prod[$x]'";
			$res2=mysql_query($con2,$conex) or die ("No se realizó con2");
			
			$con3="UPDATE cambiosventa SET clave2='$prodcambio[$x]' WHERE idCambio='$prodidcambio[$x]'";
			$res3=mysql_query($con3,$conex) or die ("No se realizó con3");
			//TERMINA ACTUALIZACION DEL CAMBIO
			$prod[$x]=$prodcambio[$x];
		}
		else
		{
			//echo $prod[$x]."<br>";
		}
		//echo $prod[$x]."<br>";
		//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
		$cons411="SELECT clasificacion FROM productos WHERE clave='$prod[$x]'";
		$res411=mysql_query($cons411,$conex) or die (mysql_error());
		$clas1=mysql_result($res411,0,'clasificacion');
		if($clas1 == 'Incontables')
		{
			$cons04="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res04=mysql_query($cons04,$conex) or die ("No se realizo cons04");
		}
		else
		{
			$cons004="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res004=mysql_query($cons004,$conex) or die ("No se realizo cons004");
			
			$cons400="SELECT existencia FROM almacenes WHERE idProducto='$prod[$x]'" ;
			$res400=mysql_query($cons400,$conex) or die ("No se pudo consultar existencias cons400");
			$existen001=mysql_result($res400,0,'existencia');
			
			$nueva=0;
			$nueva=$existen001 - $entrega[$x];

			$cons410="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'" ;
			$res410=mysql_query($cons410,$conex) or die ("No se pudo actualizar existencia cons410");
		}
	}
/*	
	if ($entrega[$x]== "")
	{}
	else
	{
		//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
		$cons411="SELECT clasificacion FROM productos WHERE clave='$prod[$x]'";
		$res411=mysql_query($cons411,$conex) or die (mysql_error());
		$clas1=mysql_result($res411,0,'clasificacion');
		if($clas1 == 'Incontables')
		{
			$cons04="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res04=mysql_query($cons04,$conex) or die ("No se realizo cons04");
		}
		else
		{
			$cons004="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res004=mysql_query($cons004,$conex) or die ("No se realizo cons004");
			
			$cons400="SELECT existencia FROM almacenes WHERE idProducto='$prod[$x]'" ;
			$res400=mysql_query($cons400,$conex) or die ("No se pudo consultar existencias cons400");
			$existen001=mysql_result($res400,0,'existencia');
			
			$nueva=0;
			$nueva=$existen001 - $entrega[$x];

			$cons410="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'" ;
			$res410=mysql_query($cons410,$conex) or die ("No se pudo actualizar existencia cons410");
		}
		
//AQUI VA COMENTADO
		if ($existencia < $entrega[$x])
		{
			$nueva=$existencia - $entrega[$x];
			
			$cons4="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$prod[$x]','$entrega[$x]','$fecha')";
			$res4=mysql_query($cons4,$conex) or die ("No se realizo cons4");
			
			$cons41="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$prod[$x]'" ;
			$res41=mysql_query($cons41,$conex) or die ("No se pudo actualizar existencia");
		}
		else
		{}
	}
*/			
}

//================== REALIZAR CAMBIOS DE MATERIAL
/*
echo "Listado de cambios<br>";

@$idcambio=$_POST['idcambio'];
@$cambio=$_POST['cambio'];
echo sizeof($idcambio)." -><br>";

if ($idcambio != "")
{
		for($x=0; $x < sizeof($idcambio); $x++)
		{
		
		$con1="SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$x]'";
		$res1=mysql_query($con1,$conex) or die ("No se realizó con1");
		$clave1=mysql_result($res1,0,'clave1');
		$clave2=mysql_result($res1,0,'clave2');
		
		echo $idcambio[$x]." - ";
		echo $clave1." por ".$cambio[$x]." <br>";

			//echo $idcambio[$x]." --- ";
			//echo $cambio[$x]." <br>";

			//OBTENER SALIDA Y CLAVE PARA ACTUALIZAR EN LA VENTA
			$con1="SELECT clave1,clave2 FROM cambiosventa WHERE idCambio='$idcambio[$x]'";
			$res1=mysql_query($con1,$conex) or die ("No se realizó con1");
			$clave1=mysql_result($res1,0,'clave1');
			$clave2=mysql_result($res1,0,'clave2');
			
			if ($clave2=='')
			{
				
				$con2="UPDATE contenido_salida SET idProducto='$cambio[$x]' WHERE idSalida='$folio' and idProducto='$clave1'";
				$res2=mysql_query($con2,$conex) or die ("No se realizó con2");

				$cons40="UPDATE entregas_material SET clave='$cambio[$x]' WHERE idSalida='$folio' and clave='$clave1'";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons40_1");
			}
			else
			{
				$con2="UPDATE contenido_salida SET idProducto='$cambio[$x]' WHERE idSalida='$folio' and idProducto='$clave2'";
				$res2=mysql_query($con2,$conex) or die ("No se realizó con2");

				$cons40="UPDATE entregas_material SET clave='$cambio[$x]' WHERE idSalida='$folio' and clave='$clave2'";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons40_2");
			}

			$con3="UPDATE cambiosventa SET clave2='$cambio[$x]' WHERE idCambio='$idcambio[$x]'";
			$res3=mysql_query($con3,$conex) or die ("No se realizó con3");

		}
}
*/

//=================== INSERCION DE PRODUCTO NUEVO
$cuantos=$_POST['cuantos'];
//echo $cuantos;
	
for($x=1; $x <= $cuantos; $x++)
{
	@$variable1="nombre".$x."_hidden";
	$clave=$_POST[$variable1];
	@$variable2="cantidad".$x;
	$cantidad=$_POST[$variable2];
	
	//echo $clave." --> ".$cantidad."<br>";
	
	if ($clave != "")
	{
		if ($cantidad != "")
		{
			//verifico si existe el producto ya en el paquete
			$cons10="SELECT * FROM contenido_salida WHERE idProducto='$clave' and idSalida='$consfolio'";
			$res10=mysql_query($cons10,$conex) or die ("No se realizo cons10");		
			$num_filas=mysql_num_rows($res10);
			
			if ($num_filas == 0)
			{
				$cons30="INSERT INTO contenido_salida (idSalida,idProducto,cantidad,entregado) VALUES ('$consfolio','$clave','$cantidad','Si')";
				$res30=mysql_query($cons30,$conex) or die ("No se realizó cons30");
				
				$cons40="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$clave','$cantidad','$fecha')";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons4");
				
				$mensaje="Producto ".$clave." agregado";
				
				// ================== VALIDO SI YA EXISTE UNO DEL MISMO TIPO LE RESTO LA DISPONIBILIDAD
				/*
				$query01="SELECT nombre FROM productos WHERE clave='$clave'";
				$result01=mysql_query($query01,$conex) or die ("No se realizo query01");
				$nombre1=mysql_result($result01,0,'nombre');
				$palabra1 = explode(" ", $nombre1);
				$palabranueva=$palabra1[0]." ".$palabra1[1];
				
				$query02="SELECT idProducto,cantidad FROM contenido_salida WHERE idSalida='$consfolio'";
				$result02=mysql_query($query02,$conex) or die ("No se realizo query02");		
				while ($fila = mysql_fetch_array($result02))
				{
					$query03="SELECT nombre FROM productos WHERE clave='$fila[0]'";
					$result03=mysql_query($query03,$conex) or die ("No se realizo query03");		
					$nombre2=mysql_result($result03,0,'nombre');
					$palabra2 = explode(" ",$nombre2);
					@$palabraexistente=$palabra2[0]." ".$palabra2[1];
					
					if($palabranueva==$palabraexistente)
					{
						$nuevacantidad = $fila[1] - $cantidad;
						$query04="UPDATE contenido_salida SET cantidad='$nuevacantidad' WHERE idSalida='$consfolio' and idProducto='$fila[0]'";
						$result04=mysql_query($query04,$conex) or die ("No se realizó query04");
					}
					else
					{
						if($palabra1[0]==$palabra2[0])
						{
							$nuevacantidad=$fila[1]-$cantidad;
							$query04="UPDATE contenido_salida SET cantidad='$nuevacantidad' WHERE idSalida='$consfolio' and idProducto='$fila[0]'";
							$result04=mysql_query($query04,$conex) or die ("No se realizó query04");
						}
					}
				}*/
			}
			else
			{
				//ACTUALIZACION DE CANTIDAD CUANDO ES EL MISMO PRODUCTO
				/*
				$cant_anterior=mysql_result($res10,0,'cantidad');
				$cant_final=$cant_anterior + $cantidad;
				
				$cons20="UPDATE contenido_salida SET cantidad='$cant_final',entregado='Si' WHERE idSalida='$consfolio' and idProducto='$clave'";
				$res20=mysql_query($cons20,$conex) or die ("No se realizó cons20");
				*/
				
				$cons40="INSERT INTO entregas_material (idSalida,clave,entregado,fecha) VALUES ('$folio','$clave','$cantidad','$fecha')";
				$res40=mysql_query($cons40,$conex) or die ("No se realizo cons4");
				
				$mensaje="Producto ".$clave." agregado";
				
			}

			// ACTUALIZO INVENTARIO 
			//VALIDO SI ES INCONTABLE PARA NO ACTUALIZAR SALIDA	
			$cons412="SELECT clasificacion FROM productos WHERE clave='$clave'";
			$res412=mysql_query($cons412,$conex) or die (mysql_error());
			@$clas=mysql_result($res412,0,'clasificacion');
			if($clas != 'Incontables')
			{
				$nueva=0;
				$cons401="SELECT existencia FROM almacenes WHERE idProducto='$clave'" ;
				$res401=mysql_query($cons401,$conex) or die ("No se pudo consultar existencias cons401");
				@$existencia=mysql_result($res401,0,'existencia');
				
				$nueva=$existencia - $cantidad;
					
				$cons402="UPDATE almacenes SET existencia='$nueva' WHERE idProducto='$clave'" ;
				$res402=mysql_query($cons402,$conex) or die ("No se pudo actualizar existencia cons402");
			}
			
		}
		else
		{ //$mensaje="ˇPara agregar el producto falta la cantidad entregada!";
			$mensaje=""; }
	}
	else
	{ //$mensaje="ˇPara agregar producto falta que seleccione alguno!"; 
		$mensaje="";}
}

// GUARDO OBSERVACIONES
$observaciones=$_POST['observaciones'];

$consob="UPDATE salida SET observaciones='$observaciones' WHERE idSalida='$consfolio'";
$resob=mysql_query($consob,$conex) or die ("No se realizó consob");
?>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
<title>Clinisys :. Universidad Cuauht&eacute;moc Plantel Aguascalientes</title>
<link href="ucaestilos.css" rel="stylesheet" type="text/css" />
<style type="text/css">
<!--
body {
	background-color: #CCCCCC;
}
.Estilo3 {color: #000000}
-->
</style></head>
<body>
<table width="800" border="0" align="center" cellpadding="0" cellspacing="0" bgcolor="#FFFFFF">
  <tr>
    <td><img src="img/top04.jpg" width="800" height="40" /></td>
  </tr>
  <tr>
    <td><table width="790" border="0" align="center">
      <tr>
        <td><table width="100%" border="0" cellspacing="0" cellpadding="0">
            <tr>
              <td><div align="center" class="style77">ENTREGA DE MATERIAL REALIZADO CON &Eacute;XITO</div></td>
            </tr>
          </table>
            <table width="100%" border="0" align="center" cellspacing="0">
              <tr>
                <td width="23%"><hr /></td>
                <td width="54%" align="center"><span class="style7">No. Control del Ticket # <span class="style9"><?php echo $consfolio; ?> </span></span></td>
                <td width="23%"><hr /></td>
              </tr>
            </table>
              <div id="contenido">
 <?php
echo "<table border=0 align='center' cellpadding='2'>";
echo "<tr bgcolor='#4E5B7B' class='titulo'>";

echo "<td class='style4' align='center'>";
echo " Id ";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Nombre";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Derecho a";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Presentaci&oacute;n";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Entregado";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Devuelto";
echo "</td>";

echo "<td class='style4' align='center'>";
echo "Disponible";
echo "</td>";

echo "</tr>";

include ("conexion.php");

$conteo=0;
	$cons3="SELECT idProducto,cantidad,entregado FROM contenido_salida WHERE idSalida='$consfolio'";
	$res3=mysql_query($cons3,$conex) or die ("No se realizo el barrido en la tabla contenido_salida");
	while($fila2 = mysql_fetch_array($res3))
	{		

			$query="SELECT clave,nombre,clasificacion FROM productos Where clave='$fila2[0]'";
			$result=mysql_query($query,$conex) or die ("No se consultaron los productos");
			$numero_filas=mysql_num_rows($result);
			$numero_campos= mysql_num_fields($result);
			while($fila = mysql_fetch_array($result))
			{

				if ($conteo==0)
				{
				echo "<tr>";
				}
				else
				{
				echo "<tr bgcolor='#F0F0F0'>";
				}

				//CONSULTO NOMBRE DE LA PRESENTACION
				$cons1="SELECT idPresentacion FROM  productos WHERE clave='".$fila[0]."'";
				$res1=mysql_query($cons1,$conex) or die ("No consulto ID de presentacion");
				$idpresen=mysql_result($res1,0,'idPresentacion');

				$cons2="SELECT presentacion FROM presentaciones WHERE idPresentacion='$idpresen'";
				$res2=mysql_query($cons2,$conex) or die ("No consulto nombre de presentacion");
				$presen=mysql_result($res2,0,'presentacion');

				echo "<td class='style1'>";
				echo $fila[0];
				echo "</td>";

				echo "<td class='style1'>";
				echo $fila[1];
				echo "</td>";

				//CANTIDAD
				echo "<td class='titulo' bgcolor='#999999'  align='center'>";
				echo $fila2[1];
				echo "</td>";

				//IMPRIMO PRESENTACION
				echo "<td class='style1'>";
				echo $presen;
				echo "</td>";

				//YA ENTREGADOS
				$entregado=0;
				$cons20="SELECT entregado FROM entregas_material WHERE clave='$fila[0]' and idSalida='$consfolio'";
				$res20=mysql_query($cons20,$conex) or die ("No consulto entregados");
				$filasent=mysql_num_rows($res20);

				if ($filasent==0)
				{
					$entregado=0;
				}
				else
				{
					while($entrega=mysql_fetch_row($res20))
					{
						$entregado=$entregado + $entrega[0];
					}
				}

				echo "<td class='style10' align='center'>";
				echo $entregado;
				echo "</td>";
				
				//DEVUELTOS
				$devoltotal=0;
				$cons21="SELECT cantidad FROM devolucionesmaterial WHERE clave='$fila[0]' and idSalida='$consfolio'";
				$res21=mysql_query($cons21,$conex) or die ("No consulto devueltos");
				$filasdev=mysql_num_rows($res21);
				
				if ($filasdev==0)
				{
					$devoltotal=0;
				}
				else
				{
					while($devueltos=mysql_fetch_row($res21))
					{
						$devoltotal=$devoltotal + $devueltos[0];
					}
				}
				
				echo "<td class='style10' align='center'>";
				echo $devoltotal;
				echo "</td>";

				//DISPONIBLES
				$quedan1=$entregado - $devoltotal;
				$quedan=$fila2[1] - $quedan1;

				//DISPONIBLES
				//$quedan=$fila2[1] - $entregado;
				
				echo "<td class='style10' align='center'>";
				echo $quedan;
				echo"<input name='quedan".$fila[0]."' type='hidden' class='cuadrotexto' id='quedan".$fila[0]."' size='1' value='$quedan'>";
				echo "</td>";

				$conteo=$conteo + 1;
				if ($conteo==2)
				{$conteo=0;}
			}

echo "</tr>";

}
echo "</table>";
?>
              </div>
          </td>
      </tr>
    </table>
        <div align="center"><br /><?php //echo $mensaje; ?> </div>
          <table width="298" border="0" align="center" cellpadding="0" cellspacing="5">
            <tr>
              <td class="style4 Estilo3">Observaciones:</td>
            </tr>
            <tr>
              <td><textarea name="observaciones" cols="60" rows="5" class="cuadrotexto" id="observaciones"><?php echo $observaciones; ?></textarea></td>
            </tr>
      </table>
      <table width="451" border="0" align="center" cellspacing="10">
        <tr>
          <td width="166"><form id="form1" name="form1" method="post" action="main.php?a=47">
              <div align="center">
                <p>
                  <input name="Submit2" type="submit" class="boton2" value="Regresar a entregas de material" />
                </p>
              </div>
          </form></td>
          <td width="84"><form id="form1" name="form1" method="post" action="main.php">
              <div align="center">
                <p>
                  <input name="Submit" type="submit" class="boton2" value="Volver a inicio" />
                </p>
              </div>
          </form></td>
          <td width="155">
          <form id="form1" name="form1" method="post" action="ejecutarsalida2.php?consfolio=<?php echo $consfolio; ?>">
              <div align="center">
                <p>
                  <input name="Submit2" type="submit" class="boton2" value="Agragar producto a este ticket" />
                </p>
              </div>
          </form>
          </td>
        </tr>
      </table>
<table width="100%" border="0">
          <tr>
            <td height="22" bgcolor="#4E5B7B"><table width="99%" border="0" align="center" cellpadding="2" cellspacing="0">
              <tr>
                <td width="50%"><div align="left"><span class="style8">Universidad Cuauht&eacute;moc Plantel Aguascalientes</span></div></td>
                <td width="50%"><div align="right"><span class="style8">Departamento de Sistemas / </span><a href="mailto:des.sistemas@ucuauhtemoc.edu.mx"><span class="style8">Desarrollo</span></a></div></td>
              </tr>
            </table></td>
          </tr>
      </table></td></tr>
</table>
</body>
</html>